Contributing
============

.. include:: ../CONTRIBUTING.rst

Additional Information
----------------------

More technical information lives on the wiki. 

* https://github.com/mapbox/rasterio/wiki/Development-Guide
* https://github.com/mapbox/rasterio/wiki/Exposing-GDAL-Functionality
* https://github.com/mapbox/rasterio/wiki/Cython-and-GDAL

The long term goal is to consolidate into this document.
